==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PrimaryKeyValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescription } from "./PrimaryKeyValueDescription";
/**
 * @hidden
 */
var PrimaryKeyValueDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PrimaryKeyValueDescriptionMetadata, _super);
    function PrimaryKeyValueDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PrimaryKeyValueDescriptionMetadata.b = function (a) {
        if (PrimaryKeyValueDescriptionMetadata.a == null) {
            PrimaryKeyValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PrimaryKeyValueDescriptionMetadata.c(PrimaryKeyValueDescriptionMetadata.a);
        }
        if (a.g(PrimaryKeyValueDescriptionMetadata.a)) {
            return;
        }
        a.s(PrimaryKeyValueDescriptionMetadata.a);
    };
    PrimaryKeyValueDescriptionMetadata.c = function (a) {
        a.item("Key", "Array:string");
        a.item("Value", "Collection:object:Array:Object");
    };
    PrimaryKeyValueDescriptionMetadata.d = function (a) {
        PrimaryKeyValueDescriptionMetadata.b(a);
        a.u("PrimaryKeyValue", function () { return new PrimaryKeyValueDescription(); });
        a.t("PrimaryKeyValue", PrimaryKeyValueDescriptionMetadata.a);
    };
    PrimaryKeyValueDescriptionMetadata.$t = markType(PrimaryKeyValueDescriptionMetadata, 'PrimaryKeyValueDescriptionMetadata');
    PrimaryKeyValueDescriptionMetadata.a = null;
    return PrimaryKeyValueDescriptionMetadata;
}(Base));
export { PrimaryKeyValueDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PrimaryKeyValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescription } from "./PrimaryKeyValueDescription";
/**
 * @hidden
 */
var PrimaryKeyValueDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PrimaryKeyValueDescriptionMetadata, _super);
    function PrimaryKeyValueDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PrimaryKeyValueDescriptionMetadata.b = function (a) {
        if (PrimaryKeyValueDescriptionMetadata.a == null) {
            PrimaryKeyValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PrimaryKeyValueDescriptionMetadata.c(PrimaryKeyValueDescriptionMetadata.a);
        }
        if (a.j(PrimaryKeyValueDescriptionMetadata.a)) {
            return;
        }
        a.y(PrimaryKeyValueDescriptionMetadata.a);
    };
    PrimaryKeyValueDescriptionMetadata.c = function (a) {
        a.item("Key", "Array:string");
        a.item("Value", "Collection:object:Array:Object");
    };
    PrimaryKeyValueDescriptionMetadata.d = function (a) {
        PrimaryKeyValueDescriptionMetadata.b(a);
        a.aa("PrimaryKeyValue", function () { return new PrimaryKeyValueDescription(); });
        a.z("PrimaryKeyValue", PrimaryKeyValueDescriptionMetadata.a);
    };
    PrimaryKeyValueDescriptionMetadata.$t = markType(PrimaryKeyValueDescriptionMetadata, 'PrimaryKeyValueDescriptionMetadata');
    PrimaryKeyValueDescriptionMetadata.a = null;
    return PrimaryKeyValueDescriptionMetadata;
}(Base));
export { PrimaryKeyValueDescriptionMetadata };
